//---------------------------------------------------------------------------------------------------------
// This code is intended to be used on an Arduino NANO board
// In case of use with other types of board, please change accordingly the pins' assignement.
// It echoes everything received from BT on the PC screen Serial Monitor @baudrate 9600.
// A button is acquired as IPUT_PULLUP to avoid electric noise and spurious activations 
// The library SoftwareSerial works fine up to 38400 baud, while it becomes instable above that value
// It is intended to use a shield HC05 or HC06 connected to the pins 2,3. be sure to reverse the pins toward
// the HC0x (Arduino Tx on Rx of HC0x)
//---------------------------------------------------------------------------------------------------------

#include <SoftwareSerial.h>
#define ledPin 13                 // default LED on the Arduino UNO board  
#define TxPin 3                   // required by SoftwareSerial (PWM capabilities needed)
#define RxPin 2                   // required by SoftwareSerial (PWM capabilities needed)
#define ButtonPin 10              // port to acquire the pushbutton 

SoftwareSerial BTSerial(RxPin,TxPin);   // instantiate the library

char state = ' ';                 // define input buffer as char (not empty but a blank)
int ButtonState = HIGH;           // Button status initialized to OFF 

//===============================================================================================
void setup()                      // done once at reset
{
   pinMode(ButtonPin,INPUT_PULLUP); // to aquire the button: idle state HIGH (pullup) active state LOW (tied to GND)
   pinMode(ledPin,OUTPUT);        // init port mode
   BTSerial.begin(9600);          // supposed baudrate of HC05 (38400 ?)
   digitalWrite(ledPin,LOW);      // initialize the local LED to off
   Serial.begin(9600);            // Used to echo on PC monitor the data received on BT
   Serial.println("HELLO");       // I'm alive
   BTSerial.println("Hello");       // I'm alive
}


//===============================================================================================
void loop()                       // repeated forever
{
  if (BTSerial.available())       // any char from BT ?
  {
    state = BTSerial.read();      // yes, get it
    Serial.print("Received : ");  // echoes it on the PC screen
    Serial.println(state);
    if(state=='0')                // the received char to switch off the led
    digitalWrite(ledPin,LOW);
    if(state=='1')                // the received char to switch on the led
    digitalWrite(ledPin,HIGH);
    BTSerial.println(state);      // do the loopback to AI2
  }
  if(digitalRead(ButtonPin) != ButtonState)     // sends the updated status only if changed
  {
    ButtonState = digitalRead(ButtonPin);       // new status stored for next comparison
    if(ButtonState == HIGH)                     // Button HIGH = idle state = OFF
    {
      BTSerial.println("OFF");                  // sends to app on BT 
      Serial.println("Button not pressed");     // sends to Serial Monitor for debug purposes 
    }
      else                                      // Button LOW = active state = ON
      {
        BTSerial.println("ON");                 // sends to app on BT 
        Serial.println("Button pressed");       // sends to Serial Monitor for debug purposes 
      }
  }
}
